@@ -8,6 +8,8 @@ sub change { shift->render }
 sub show {
   my $self = shift;
 
+  print STDERR 'Admin::show()',"\n";
+  
   #my $table = $self->stash->{table};
 
   $self->render;
@@ -26,6 +28,21 @@ sub save {
 
   $data->{$_} = $self->req->param($_) ? $self->req->param($_) : 0
     for (@$params);
+    
+  for my $param (@$params) {
+    if ($form->elements->{$param}->{type} eq 'text' ) {
+     $data->{$param} =
+      $self->req->param($param) ? $self->req->param($param) : '';       
+    }
+    elsif ($form->elements->{$param}->{type} eq 'number' ) {
+     $data->{$param} =
+      $self->req->param($param) ? $self->req->param($param) : 0;       
+    }
+    else {
+     $data->{$param} =
+      $self->req->param($param) ? $self->req->param($param) : undef;       
+    }    
+  } 
 
   my @elements = @{$form->ordered_elements};
 
@@ -38,9 +55,11 @@ sub save {
   }
 
   my $id_field = $form->id_field;
+  say STDERR 'Admin::save() $id_field: ',$id_field if $self->app->app_debug;
   if (exists $data->{$id_field} && !$data->{$id_field}) {
     delete $data->{$id_field};
   }
+  say STDERR 'Admin::save() $data: ',Dumper($data) if $self->app->app_debug;
 
   my $rs = $self->schema->resultset($table);
   $rs->update_or_create($data);
