@@ -11,11 +11,11 @@ __PACKAGE__->add_columns(
   'orderitem_id',
   {data_type => 'integer', is_auto_increment => 1, is_nullable => 0},
   'order_id',
-  {data_type => 'integer', is_nullable => 0},
+  {data_type => 'integer', is_nullable => 0, is_foreign_key => 1},
   'line_item_id',
   {data_type => 'integer', is_nullable => 0},
   'article_id',
-  {data_type => 'integer', is_nullable => 0},
+  {data_type => 'integer', is_nullable => 0, is_foreign_key => 1},
   'quantity',
   {
     data_type     => 'decimal',
@@ -24,7 +24,12 @@ __PACKAGE__->add_columns(
     size          => [10, 2],
   },
   'unit_id',
-  {data_type => 'integer', default_value => 1, is_nullable => 0},
+  {
+    data_type      => 'integer',
+    default_value  => 1,
+    is_nullable    => 0,
+    is_foreign_key => 1
+  },
   'article_price',
   {
     data_type     => 'decimal',
@@ -49,9 +54,9 @@ __PACKAGE__->add_columns(
 
 __PACKAGE__->set_primary_key('orderitem_id');
 
-__PACKAGE__->belongs_to('orders', 'AproJo::DB::Schema::Result::Order',
+__PACKAGE__->belongs_to('order', 'AproJo::DB::Schema::Result::Order',
   'order_id');
-__PACKAGE__->belongs_to('articles', 'AproJo::DB::Schema::Result::Article',
+__PACKAGE__->belongs_to('article', 'AproJo::DB::Schema::Result::Article',
   'article_id');
 __PACKAGE__->belongs_to('unit', 'AproJo::DB::Schema::Result::Unit', 'unit_id');
 
