@@ -11,13 +11,13 @@ __PACKAGE__->table('preferences');
 
 __PACKAGE__->add_columns(
   'user_id',
-  {data_type => 'integer', is_nullable => 0},
-  'option',
+  {data_type => 'integer', is_nullable => 0,is_foreign_key => 1},
+  'name',
   {data_type => 'varchar', default_value => '', is_nullable => 0, size => 255},
   'value',
   {data_type => 'varchar', default_value => '', is_nullable => 0, size => 255},
 );
 
-__PACKAGE__->set_primary_key('user_id', 'option');
+__PACKAGE__->set_primary_key('user_id', 'name');
 
 1;
