@@ -1,5 +1,3 @@
-use utf8;
-
 package AproJo::DB::Schema::Result::Usertime;
 
 use strict;
@@ -13,7 +11,7 @@ __PACKAGE__->add_columns(
   'usertimes_id',
   {data_type => 'integer', is_auto_increment => 1, is_nullable => 0},
   'user_id',
-  {data_type => 'integer', is_nullable => 0},
+  {data_type => 'integer', is_nullable => 0, is_foreign_key => 1},
   'start',
   {
     data_type                 => 'datetime',
